@@ -20,7 +20,6 @@
 
 #include <QAction>
 #include <QActionGroup>
-#include <QSignalMapper>
 #include <QUndoStack>
 #include <QUrl>
 
@@ -310,8 +309,6 @@ class KWordQuizApp : public KXmlGuiWindow
     QAction * quizOpt2;
     QAction * quizOpt3;
 
-    QSignalMapper* charMapper;
-
     QAction* configShowSearchBar;
 
     KDirWatch * m_dirWatch;
